summaryrefslogtreecommitdiffstats
path: root/src/urlnavigatorbutton.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2e11795ab3befef25e318902869fa71c6ff4a076 (patch)
treeb5ec2f60aef32f350fc5b56720bc616c44a840c6 /src/urlnavigatorbutton.cpp
parent10b4cb5e889a28380c1cc4d5e4ebe01a835df6d9 (diff)
downloaddolphin-2e11795ab3befef25e318902869fa71c6ff4a076.tar.gz
dolphin-2e11795ab3befef25e318902869fa71c6ff4a076.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/dolphin@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/urlnavigatorbutton.cpp')
-rw-r--r--src/urlnavigatorbutton.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/urlnavigatorbutton.cpp b/src/urlnavigatorbutton.cpp
index bc0e7b5..8d893f9 100644
--- a/src/urlnavigatorbutton.cpp
+++ b/src/urlnavigatorbutton.cpp
@@ -38,8 +38,8 @@
#include "dolphinview.h"
#include "dolphin.h"
-URLNavigatorButton::URLNavigatorButton(int index, URLNavigator* tqparent) :
- URLButton(tqparent),
+URLNavigatorButton::URLNavigatorButton(int index, URLNavigator* parent) :
+ URLButton(parent),
m_index(-1),
m_listJob(0)
{
@@ -108,7 +108,7 @@ void URLNavigatorButton::drawButton(TQPainter* painter)
foregroundColor = KGlobalSettings::buttonTextColor();
}
// dimm the colors if the tqparent view does not have the focus
const DolphinView* parentView = urlNavigator()->dolphinView();
const Dolphin& dolphin = Dolphin::mainWin();
@@ -108,7 +108,7 @@ void URLNavigatorButton::drawButton(TQPainter* painter)
foregroundColor = KGlobalSettings::buttonTextColor();
}
- // dimm the colors if the tqparent view does not have the focus
+ // dimm the colors if the parent view does not have the focus
const DolphinView* parentView = urlNavigator()->dolphinView();
const Dolphin& dolphin = Dolphin::mainWin();